package com.os.mes.base.service.impl;

import java.util.List;
import com.os.common.utils.DateUtils;
import com.os.common.utils.StringUtils;
import com.os.mes.base.domain.BaseProductLine;
import com.os.mes.base.mapper.BaseProductLineMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.mes.base.mapper.BaseDeviceLedgerMapper;
import com.os.mes.base.domain.BaseDeviceLedger;
import com.os.mes.base.service.IBaseDeviceLedgerService;

/**
 * 设备台账Service业务层处理
 * 
 * @author Yinq
 * @date 2024-05-10
 */
@Service
public class BaseDeviceLedgerServiceImpl implements IBaseDeviceLedgerService 
{
    @Autowired
    private BaseDeviceLedgerMapper baseDeviceLedgerMapper;

    @Autowired
    private BaseProductLineMapper baseProductLineMapper;

    /**
     * 查询设备台账
     * 
     * @param objId 设备台账主键
     * @return 设备台账
     */
    @Override
    public BaseDeviceLedger selectBaseDeviceLedgerByObjId(Long objId)
    {
        return baseDeviceLedgerMapper.selectBaseDeviceLedgerByObjId(objId);
    }

    /**
     * 查询设备台账列表
     * 
     * @param baseDeviceLedger 设备台账
     * @return 设备台账
     */
    @Override
    public List<BaseDeviceLedger> selectBaseDeviceLedgerList(BaseDeviceLedger baseDeviceLedger)
    {
        return baseDeviceLedgerMapper.selectBaseDeviceLedgerList(baseDeviceLedger);
    }

    /**
     * 新增设备台账
     * 
     * @param baseDeviceLedger 设备台账
     * @return 结果
     */
    @Override
    public int insertBaseDeviceLedger(BaseDeviceLedger baseDeviceLedger)
    {
        baseDeviceLedger.setCreateTime(DateUtils.getNowDate());
        return baseDeviceLedgerMapper.insertBaseDeviceLedger(baseDeviceLedger);
    }

    /**
     * 修改设备台账
     * 
     * @param baseDeviceLedger 设备台账
     * @return 结果
     */
    @Override
    public int updateBaseDeviceLedger(BaseDeviceLedger baseDeviceLedger)
    {
        baseDeviceLedger.setUpdateTime(DateUtils.getNowDate());
        return baseDeviceLedgerMapper.updateBaseDeviceLedger(baseDeviceLedger);
    }

    /**
     * 批量删除设备台账
     * 
     * @param objIds 需要删除的设备台账主键
     * @return 结果
     */
    @Override
    public int deleteBaseDeviceLedgerByObjIds(Long[] objIds)
    {
        return baseDeviceLedgerMapper.deleteBaseDeviceLedgerByObjIds(objIds);
    }

    /**
     * 删除设备台账信息
     * 
     * @param objId 设备台账主键
     * @return 结果
     */
    @Override
    public int deleteBaseDeviceLedgerByObjId(Long objId)
    {
        return baseDeviceLedgerMapper.deleteBaseDeviceLedgerByObjId(objId);
    }

    /**
     * 获取设备编号
     * @return
     */
    @Override
    public String getDeviceCode() {
        int incrementedNumber = 1;
        String deviceCode = baseDeviceLedgerMapper.getDeviceCode();
        if (StringUtils.isNotEmpty(deviceCode)){
            String numericPart = deviceCode.substring(1);
            // 将数字部分转换为整数并加1
            incrementedNumber = Integer.parseInt(numericPart) + 1;
        }
        // 格式化加1后的数字部分，确保总长度为5位
        String formattedNumber = String.format("%05d", incrementedNumber);
        // 拼接 'E' 和格式化后的数字部分
        return "E" + formattedNumber;
    }

    /**
     *通过设备编号查询设备台账
     * @param equipmentNo 设备台账
     * @param processStage 工艺阶段
     * @return
     */
    @Override
    public BaseDeviceLedger selectBaseDeviceLedgerByDeviceCode(String equipmentNo, String processStage) {
        BaseDeviceLedger baseDeviceLedger = baseDeviceLedgerMapper.selectBaseDeviceLedgerByDeviceCode(equipmentNo);
        if (processStage.equals("出布") || processStage.equals("成型") || processStage.equals("包胶")) {
            BaseProductLine productLine = new BaseProductLine();
            productLine.setProductLineName(processStage);
            productLine.setWorkCenterCode(baseDeviceLedger.getProductLineCode());
            List<BaseProductLine> productLineList = baseProductLineMapper.selectBaseProductLineList(productLine);
            if (!productLineList.isEmpty()){
                BaseProductLine baseProductLine = productLineList.get(0);
                baseDeviceLedger.setProductLineCode(baseProductLine.getProductLineCode());//工位
                baseDeviceLedger.setProcessCode(baseProductLine.getWorkCenterName());
            }
        }
        return baseDeviceLedger;
    }

}
