package com.os.mes.prod.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.mes.prod.domain.ProdPlanErpInfo;
import com.os.mes.prod.service.IProdPlanErpInfoService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 生产计划信息Controller
 *
 * @author Yinq
 * @date 2024-08-22
 */
@RestController
@RequestMapping("/mes/prod/prodPlanErpInfo")
public class ProdPlanErpInfoController extends BaseController {
    @Autowired
    private IProdPlanErpInfoService prodPlanErpInfoService;

    /**
     * 查询生产计划信息列表
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodPlanErpInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(ProdPlanErpInfo prodPlanErpInfo) {
        startPage();
        List<ProdPlanErpInfo> list = prodPlanErpInfoService.selectProdPlanErpInfoList(prodPlanErpInfo);
        return getDataTable(list);
    }

    /**
     * 导出生产计划信息列表
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodPlanErpInfo:export')")
    @Log(title = "生产计划信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProdPlanErpInfo prodPlanErpInfo) {
        List<ProdPlanErpInfo> list = prodPlanErpInfoService.selectProdPlanErpInfoList(prodPlanErpInfo);
        ExcelUtil<ProdPlanErpInfo> util = new ExcelUtil<ProdPlanErpInfo>(ProdPlanErpInfo.class);
        util.exportExcel(response, list, "生产计划信息数据");
    }

    /**
     * 获取生产计划信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodPlanErpInfo:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(prodPlanErpInfoService.selectProdPlanErpInfoByObjId(objId));
    }

    /**
     * 新增生产计划信息
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodPlanErpInfo:add')")
    @Log(title = "生产计划信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProdPlanErpInfo prodPlanErpInfo) {
        prodPlanErpInfo.setCreateBy(getUsername());
        return toAjax(prodPlanErpInfoService.insertProdPlanErpInfo(prodPlanErpInfo));
    }

    /**
     * 修改生产计划信息
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodPlanErpInfo:edit')")
    @Log(title = "生产计划信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProdPlanErpInfo prodPlanErpInfo) {
        prodPlanErpInfo.setUpdateBy(getUsername());
        return toAjax(prodPlanErpInfoService.updateProdPlanErpInfo(prodPlanErpInfo));
    }

    /**
     * 删除生产计划信息
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:prodPlanErpInfo:remove')")
    @Log(title = "生产计划信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(prodPlanErpInfoService.deleteProdPlanErpInfoByObjIds(objIds));
    }
}
