package com.os.mes.prod.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.mes.prod.domain.ProdPlanExecuteUser;
import com.os.mes.prod.service.IProdPlanExecuteUserService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 生产工单执行用户Controller
 *
 * @author Yinq
 * @date 2024-09-26
 */
@RestController
@RequestMapping("/mes/prod/planExecuteUser")
public class ProdPlanExecuteUserController extends BaseController {
    @Autowired
    private IProdPlanExecuteUserService prodPlanExecuteUserService;

    /**
     * 查询生产工单执行用户列表
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:planExecuteUser:list')")
    @GetMapping("/list")
    public TableDataInfo list(ProdPlanExecuteUser prodPlanExecuteUser) {
        startPage();
        List<ProdPlanExecuteUser> list = prodPlanExecuteUserService.selectProdPlanExecuteUserList(prodPlanExecuteUser);
        return getDataTable(list);
    }

    /**
     * 导出生产工单执行用户列表
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:planExecuteUser:export')")
    @Log(title = "生产工单执行用户", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProdPlanExecuteUser prodPlanExecuteUser) {
        List<ProdPlanExecuteUser> list = prodPlanExecuteUserService.selectProdPlanExecuteUserList(prodPlanExecuteUser);
        ExcelUtil<ProdPlanExecuteUser> util = new ExcelUtil<ProdPlanExecuteUser>(ProdPlanExecuteUser.class);
        util.exportExcel(response, list, "生产工单执行用户数据");
    }

    /**
     * 获取生产工单执行用户详细信息
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:planExecuteUser:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(prodPlanExecuteUserService.selectProdPlanExecuteUserByObjId(objId));
    }

    /**
     * 新增生产工单执行用户
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:planExecuteUser:add')")
    @Log(title = "生产工单执行用户", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProdPlanExecuteUser prodPlanExecuteUser) {
        prodPlanExecuteUser.setCreateBy(getUsername());
        return toAjax(prodPlanExecuteUserService.insertProdPlanExecuteUser(prodPlanExecuteUser));
    }

    /**
     * 修改生产工单执行用户
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:planExecuteUser:edit')")
    @Log(title = "生产工单执行用户", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProdPlanExecuteUser prodPlanExecuteUser) {
        prodPlanExecuteUser.setUpdateBy(getUsername());
        return toAjax(prodPlanExecuteUserService.updateProdPlanExecuteUser(prodPlanExecuteUser));
    }

    /**
     * 删除生产工单执行用户
     */
    @PreAuthorize("@ss.hasPermi('mes/prod:planExecuteUser:remove')")
    @Log(title = "生产工单执行用户", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(prodPlanExecuteUserService.deleteProdPlanExecuteUserByObjIds(objIds));
    }
}
