package com.os.mes.prod.domain;

import java.math.BigDecimal;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

import com.fasterxml.jackson.annotation.JsonFormat;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.os.common.annotation.Excel;
import com.os.common.core.domain.BaseEntity;

/**
 * 生产计划信息对象 prod_plan_erp_info
 * 
 * @author Yinq
 * @date 2024-08-22
 */
public class ProdPlanErpInfo extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键标识 */
    private Long objId;

    @Excel(name = "工作量")
    private BigDecimal workload;

    /** 硬件 */
    @Excel(name = "硬件")
    private String hardware;

    /** 软件 */
    @Excel(name = "软件")
    private String software;

    /** 阶段文字 */
    @Excel(name = "阶段文字")
    private String stageText;

    /** 计划流水号 */
    @Excel(name = "计划流水号")
    private String seqNo;

    /** 计划开始时间 */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "计划开始时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date planStartTime;

    /** 计划结束时间 */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "计划结束时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    private Date planEndTime;

    /** 关联资源 */
    @Excel(name = "关联资源")
    private String associationResource;

    /** 工作效率 */
    @Excel(name = "工作效率")
    private String workingEfficiency;

    /** 设备码 */
    @Excel(name = "设备码")
    private String equipmentNo;

    /** 准备时间（分） */
    @Excel(name = "准备时间")
    private BigDecimal preparationDuration;

    /** 收尾时间（分） */
    @Excel(name = "收尾时间")
    private BigDecimal windUpDuration;

    /** 出布最小速度（米 / 分） */
    @Excel(name = "出布最小速度")
    private BigDecimal clothMinimumSpeed;

    /** 出布最大速度（米 / 分） */
    @Excel(name = "出布最大速度")
    private BigDecimal clothMaximumSpeed;

    /** 成型最小速度（米 / 分） */
    @Excel(name = "成型最小速度")
    private BigDecimal formingMinimumSpeed;

    /** 成型最大速度（米 / 分） */
    @Excel(name = "成型最大速度")
    private BigDecimal formingMaximumSpeed;

    /** 包胶最小速度（米 / 分） */
    @Excel(name = "包胶最小速度")
    private BigDecimal glueMinimumSpeed;

    /** 包胶最大速度（米 / 分） */
    @Excel(name = "包胶最大速度")
    private BigDecimal glueMaximumSpeed;

    /** 每锅硫化米数（m） */
    @Excel(name = "每锅硫化米数")
    private BigDecimal sulfurizationLength;

    /** 硫化机类型 */
    @Excel(name = "硫化机类型")
    private String vulcanizingMachineType;

    /** 硫化板层数 */
    @Excel(name = "硫化板层数")
    private String vulcanizedBoardNumber;

    /** 资源名称 */
    @Excel(name = "资源名称")
    private String resourceName;

    /** 工艺阶段 */
    @Excel(name = "工艺阶段")
    private String processStage;

    /** 前置工艺 */
    @Excel(name = "前置工艺")
    private String preProcess;

    /** 发布订单 */
    @Excel(name = "发布订单")
    private String releaseOrder;

    /** 任务编号 */
    @Excel(name = "任务编号")
    private String taskCode;

    /** 输送带长度规格 */
    @Excel(name = "输送带长度规格")
    private String conveyorLengthSpecification;

    /** 上胶厚度（mm） */
    @Excel(name = "上胶厚度")
    private BigDecimal upGlueThickness;

    /** 上缓冲胶厚度（mm） */
    @Excel(name = "上缓冲胶厚度")
    private BigDecimal upBufferGlueThickness;

    /** 下胶厚度（mm） */
    @Excel(name = "下胶厚度")
    private BigDecimal belowGlueThickness;

    /** 下缓冲胶厚度（mm） */
    @Excel(name = "下缓冲胶厚度")
    private BigDecimal belowBufferGlueThickness;

    /** 输送带宽度（mm） */
    @Excel(name = "输送带宽度")
    private BigDecimal beltWidth;

    /** 客户要求输送带长度（m） */
    @Excel(name = "客户要求输送带长度")
    private BigDecimal customerRequestConveyorLength;

    /** 压延生产米数（m） */
    @Excel(name = "压延生产米数")
    private BigDecimal rollingProductionMeters;

    /** 需要硫化米数 */
    @Excel(name = "需要硫化米数")
    private BigDecimal vulcanizationMeters;

    /** 推荐硫化时间 */
    @Excel(name = "推荐硫化时间")
    private BigDecimal recommendVulcanizationTime;

    /** 出大布米数 */
    @Excel(name = "出大布米数")
    private BigDecimal largeClothMeters;

    /** 出小布米数 */
    @Excel(name = "出小布米数")
    private BigDecimal smallClothMeters;

    /** 包胶米数 */
    @Excel(name = "包胶米数")
    private BigDecimal encapsulationMeters;

    /** 工作速度（每小时） */
    @Excel(name = "工作速度")
    private BigDecimal workSpeed;

    /** 需要工时（小时） */
    @Excel(name = "需要工时")
    private BigDecimal workingHours;

    /** 出布面积（㎡） */
    @Excel(name = "出布面积")
    private BigDecimal distributionArea;

    /** 包胶面积（㎡） */
    @Excel(name = "包胶面积")
    private BigDecimal encapsulationArea;

    /** 硫化面积（㎡） */
    @Excel(name = "硫化面积")
    private BigDecimal vulcanizationArea;

    /** 输送带总面积（㎡） */
    @Excel(name = "输送带总面积")
    private BigDecimal conveyorTotalArea;

    /** 胶料工艺 */
    @Excel(name = "胶料工艺")
    private String glueProcess;

    /** 上胶使用胶料 */
    @Excel(name = "上胶使用胶料")
    private String upGlue;

    /** 上胶系数 */
    @Excel(name = "上胶系数")
    private BigDecimal upGlueCoefficient;

    /** 上胶标准用胶量（KG） */
    @Excel(name = "上胶标准用胶量")
    private BigDecimal upGlueDosage;

    /** 下胶使用胶料 */
    @Excel(name = "下胶使用胶料")
    private String belowGlue;

    /** 下胶系数 */
    @Excel(name = "下胶系数")
    private BigDecimal belowGlueCoefficient;

    /** 下胶标准用胶量（KG） */
    @Excel(name = "下胶标准用胶量")
    private BigDecimal belowGlueDosage;

    /** 缓冲/布胶使用胶料 */
    @Excel(name = "缓冲/布胶使用胶料")
    private String bufferGlue;

    /** 缓冲胶系数 */
    @Excel(name = "缓冲胶系数")
    private BigDecimal bufferGlueCoefficient;

    /** 缓冲胶标准用胶量（KG） */
    @Excel(name = "缓冲胶标准用胶量")
    private BigDecimal bufferGlueDosage;

    /** 大布布料规格 */
    @Excel(name = "大布布料规格")
    private BigDecimal largeClothSpecifications;

    /** 大布擦胶系数 */
    @Excel(name = "大布擦胶系数")
    private BigDecimal largeClothFrictioningCoefficient;

    /** 胶布标准用胶量（KG） */
    @Excel(name = "胶布标准用胶量")
    private BigDecimal largeClothDosage;

    /** 中间胶使用胶料 */
    @Excel(name = "中间胶使用胶料")
    private String middleGlue;

    /** 中间胶系数 */
    @Excel(name = "中间胶系数")
    private BigDecimal middleGlueCoefficient;

    /** 中间胶标准用胶量（KG） */
    @Excel(name = "中间胶标准用胶量")
    private BigDecimal middleGlueDosage;

    /** 设备使用限制 */
    @Excel(name = "设备使用限制")
    private String deviceUsageRestrictions;

    /** 判断工段 */
    @Excel(name = "判断工段")
    private String workshopSection;

    /** 班次 */
    @Excel(name = "班次")
    private String classes;

    /** 参加任务小组 */
    @Excel(name = "参加任务小组")
    private String taskForce;

    /** 班组名称 */
    @Excel(name = "班组名称")
    private String teamName;

    /** 组长 */
    @Excel(name = "组长")
    private String groupLeader;

    /** 小组编号 */
    @Excel(name = "小组编号")
    private String teamNo;

    /** 人员活动详情 */
    @Excel(name = "人员活动详情")
    private List<HashMap<String, String>> personnelOperationDetails;

    private String processCode;
    private String stationCode;

    public BigDecimal getWorkload() {
        return workload;
    }

    public void setWorkload(BigDecimal workload) {
        this.workload = workload;
    }

    public String getTeamNo() {
        return teamNo;
    }

    public void setTeamNo(String teamNo) {
        this.teamNo = teamNo;
    }

    public String getProcessCode() {
        return processCode;
    }

    public void setProcessCode(String processCode) {
        this.processCode = processCode;
    }

    public String getStationCode() {
        return stationCode;
    }

    public void setStationCode(String stationCode) {
        this.stationCode = stationCode;
    }

    public void setObjId(Long objId)
    {
        this.objId = objId;
    }

    public Long getObjId() 
    {
        return objId;
    }
    public void setHardware(String hardware) 
    {
        this.hardware = hardware;
    }

    public String getHardware() 
    {
        return hardware;
    }
    public void setSoftware(String software) 
    {
        this.software = software;
    }

    public String getSoftware() 
    {
        return software;
    }
    public void setStageText(String stageText) 
    {
        this.stageText = stageText;
    }

    public String getStageText() 
    {
        return stageText;
    }
    public void setSeqNo(String seqNo) 
    {
        this.seqNo = seqNo;
    }

    public String getSeqNo() 
    {
        return seqNo;
    }
    public void setPlanStartTime(Date planStartTime) 
    {
        this.planStartTime = planStartTime;
    }

    public Date getPlanStartTime() 
    {
        return planStartTime;
    }
    public void setPlanEndTime(Date planEndTime) 
    {
        this.planEndTime = planEndTime;
    }

    public Date getPlanEndTime() 
    {
        return planEndTime;
    }
    public void setAssociationResource(String associationResource) 
    {
        this.associationResource = associationResource;
    }

    public String getAssociationResource() 
    {
        return associationResource;
    }
    public void setWorkingEfficiency(String workingEfficiency) 
    {
        this.workingEfficiency = workingEfficiency;
    }

    public String getWorkingEfficiency() 
    {
        return workingEfficiency;
    }
    public void setEquipmentNo(String equipmentNo) 
    {
        this.equipmentNo = equipmentNo;
    }

    public String getEquipmentNo() 
    {
        return equipmentNo;
    }
    public void setPreparationDuration(BigDecimal preparationDuration) 
    {
        this.preparationDuration = preparationDuration;
    }

    public BigDecimal getPreparationDuration() 
    {
        return preparationDuration;
    }
    public void setWindUpDuration(BigDecimal windUpDuration) 
    {
        this.windUpDuration = windUpDuration;
    }

    public BigDecimal getWindUpDuration() 
    {
        return windUpDuration;
    }
    public void setClothMinimumSpeed(BigDecimal clothMinimumSpeed) 
    {
        this.clothMinimumSpeed = clothMinimumSpeed;
    }

    public BigDecimal getClothMinimumSpeed() 
    {
        return clothMinimumSpeed;
    }
    public void setClothMaximumSpeed(BigDecimal clothMaximumSpeed) 
    {
        this.clothMaximumSpeed = clothMaximumSpeed;
    }

    public BigDecimal getClothMaximumSpeed() 
    {
        return clothMaximumSpeed;
    }
    public void setFormingMinimumSpeed(BigDecimal formingMinimumSpeed) 
    {
        this.formingMinimumSpeed = formingMinimumSpeed;
    }

    public BigDecimal getFormingMinimumSpeed() 
    {
        return formingMinimumSpeed;
    }
    public void setFormingMaximumSpeed(BigDecimal formingMaximumSpeed) 
    {
        this.formingMaximumSpeed = formingMaximumSpeed;
    }

    public BigDecimal getFormingMaximumSpeed() 
    {
        return formingMaximumSpeed;
    }
    public void setGlueMinimumSpeed(BigDecimal glueMinimumSpeed) 
    {
        this.glueMinimumSpeed = glueMinimumSpeed;
    }

    public BigDecimal getGlueMinimumSpeed() 
    {
        return glueMinimumSpeed;
    }
    public void setGlueMaximumSpeed(BigDecimal glueMaximumSpeed) 
    {
        this.glueMaximumSpeed = glueMaximumSpeed;
    }

    public BigDecimal getGlueMaximumSpeed() 
    {
        return glueMaximumSpeed;
    }
    public void setSulfurizationLength(BigDecimal sulfurizationLength) 
    {
        this.sulfurizationLength = sulfurizationLength;
    }

    public BigDecimal getSulfurizationLength() 
    {
        return sulfurizationLength;
    }
    public void setVulcanizingMachineType(String vulcanizingMachineType) 
    {
        this.vulcanizingMachineType = vulcanizingMachineType;
    }

    public String getVulcanizingMachineType() 
    {
        return vulcanizingMachineType;
    }
    public void setVulcanizedBoardNumber(String vulcanizedBoardNumber) 
    {
        this.vulcanizedBoardNumber = vulcanizedBoardNumber;
    }

    public String getVulcanizedBoardNumber() 
    {
        return vulcanizedBoardNumber;
    }
    public void setResourceName(String resourceName) 
    {
        this.resourceName = resourceName;
    }

    public String getResourceName() 
    {
        return resourceName;
    }
    public void setProcessStage(String processStage) 
    {
        this.processStage = processStage;
    }

    public String getProcessStage() 
    {
        return processStage;
    }
    public void setPreProcess(String preProcess) 
    {
        this.preProcess = preProcess;
    }

    public String getPreProcess() 
    {
        return preProcess;
    }
    public void setReleaseOrder(String releaseOrder) 
    {
        this.releaseOrder = releaseOrder;
    }

    public String getReleaseOrder() 
    {
        return releaseOrder;
    }
    public void setTaskCode(String taskCode) 
    {
        this.taskCode = taskCode;
    }

    public String getTaskCode() 
    {
        return taskCode;
    }
    public void setConveyorLengthSpecification(String conveyorLengthSpecification) 
    {
        this.conveyorLengthSpecification = conveyorLengthSpecification;
    }

    public String getConveyorLengthSpecification() 
    {
        return conveyorLengthSpecification;
    }
    public void setUpGlueThickness(BigDecimal upGlueThickness) 
    {
        this.upGlueThickness = upGlueThickness;
    }

    public BigDecimal getUpGlueThickness() 
    {
        return upGlueThickness;
    }
    public void setUpBufferGlueThickness(BigDecimal upBufferGlueThickness) 
    {
        this.upBufferGlueThickness = upBufferGlueThickness;
    }

    public BigDecimal getUpBufferGlueThickness() 
    {
        return upBufferGlueThickness;
    }
    public void setBelowGlueThickness(BigDecimal belowGlueThickness) 
    {
        this.belowGlueThickness = belowGlueThickness;
    }

    public BigDecimal getBelowGlueThickness() 
    {
        return belowGlueThickness;
    }
    public void setBelowBufferGlueThickness(BigDecimal belowBufferGlueThickness) 
    {
        this.belowBufferGlueThickness = belowBufferGlueThickness;
    }

    public BigDecimal getBelowBufferGlueThickness() 
    {
        return belowBufferGlueThickness;
    }
    public void setBeltWidth(BigDecimal beltWidth) 
    {
        this.beltWidth = beltWidth;
    }

    public BigDecimal getBeltWidth() 
    {
        return beltWidth;
    }
    public void setCustomerRequestConveyorLength(BigDecimal customerRequestConveyorLength) 
    {
        this.customerRequestConveyorLength = customerRequestConveyorLength;
    }

    public BigDecimal getCustomerRequestConveyorLength() 
    {
        return customerRequestConveyorLength;
    }
    public void setRollingProductionMeters(BigDecimal rollingProductionMeters) 
    {
        this.rollingProductionMeters = rollingProductionMeters;
    }

    public BigDecimal getRollingProductionMeters() 
    {
        return rollingProductionMeters;
    }
    public void setVulcanizationMeters(BigDecimal vulcanizationMeters) 
    {
        this.vulcanizationMeters = vulcanizationMeters;
    }

    public BigDecimal getVulcanizationMeters() 
    {
        return vulcanizationMeters;
    }
    public void setRecommendVulcanizationTime(BigDecimal recommendVulcanizationTime) 
    {
        this.recommendVulcanizationTime = recommendVulcanizationTime;
    }

    public BigDecimal getRecommendVulcanizationTime() 
    {
        return recommendVulcanizationTime;
    }
    public void setLargeClothMeters(BigDecimal largeClothMeters) 
    {
        this.largeClothMeters = largeClothMeters;
    }

    public BigDecimal getLargeClothMeters() 
    {
        return largeClothMeters;
    }
    public void setSmallClothMeters(BigDecimal smallClothMeters) 
    {
        this.smallClothMeters = smallClothMeters;
    }

    public BigDecimal getSmallClothMeters() 
    {
        return smallClothMeters;
    }
    public void setEncapsulationMeters(BigDecimal encapsulationMeters) 
    {
        this.encapsulationMeters = encapsulationMeters;
    }

    public BigDecimal getEncapsulationMeters() 
    {
        return encapsulationMeters;
    }
    public void setWorkSpeed(BigDecimal workSpeed) 
    {
        this.workSpeed = workSpeed;
    }

    public BigDecimal getWorkSpeed() 
    {
        return workSpeed;
    }
    public void setWorkingHours(BigDecimal workingHours) 
    {
        this.workingHours = workingHours;
    }

    public BigDecimal getWorkingHours() 
    {
        return workingHours;
    }
    public void setDistributionArea(BigDecimal distributionArea) 
    {
        this.distributionArea = distributionArea;
    }

    public BigDecimal getDistributionArea() 
    {
        return distributionArea;
    }
    public void setEncapsulationArea(BigDecimal encapsulationArea) 
    {
        this.encapsulationArea = encapsulationArea;
    }

    public BigDecimal getEncapsulationArea() 
    {
        return encapsulationArea;
    }
    public void setVulcanizationArea(BigDecimal vulcanizationArea) 
    {
        this.vulcanizationArea = vulcanizationArea;
    }

    public BigDecimal getVulcanizationArea() 
    {
        return vulcanizationArea;
    }
    public void setConveyorTotalArea(BigDecimal conveyorTotalArea) 
    {
        this.conveyorTotalArea = conveyorTotalArea;
    }

    public BigDecimal getConveyorTotalArea() 
    {
        return conveyorTotalArea;
    }
    public void setGlueProcess(String glueProcess) 
    {
        this.glueProcess = glueProcess;
    }

    public String getGlueProcess() 
    {
        return glueProcess;
    }
    public void setUpGlue(String upGlue) 
    {
        this.upGlue = upGlue;
    }

    public String getUpGlue() 
    {
        return upGlue;
    }
    public void setUpGlueCoefficient(BigDecimal upGlueCoefficient) 
    {
        this.upGlueCoefficient = upGlueCoefficient;
    }

    public BigDecimal getUpGlueCoefficient() 
    {
        return upGlueCoefficient;
    }
    public void setUpGlueDosage(BigDecimal upGlueDosage) 
    {
        this.upGlueDosage = upGlueDosage;
    }

    public BigDecimal getUpGlueDosage() 
    {
        return upGlueDosage;
    }
    public void setBelowGlue(String belowGlue) 
    {
        this.belowGlue = belowGlue;
    }

    public String getBelowGlue() 
    {
        return belowGlue;
    }
    public void setBelowGlueCoefficient(BigDecimal belowGlueCoefficient) 
    {
        this.belowGlueCoefficient = belowGlueCoefficient;
    }

    public BigDecimal getBelowGlueCoefficient() 
    {
        return belowGlueCoefficient;
    }
    public void setBelowGlueDosage(BigDecimal belowGlueDosage) 
    {
        this.belowGlueDosage = belowGlueDosage;
    }

    public BigDecimal getBelowGlueDosage() 
    {
        return belowGlueDosage;
    }
    public void setBufferGlue(String bufferGlue) 
    {
        this.bufferGlue = bufferGlue;
    }

    public String getBufferGlue() 
    {
        return bufferGlue;
    }
    public void setBufferGlueCoefficient(BigDecimal bufferGlueCoefficient) 
    {
        this.bufferGlueCoefficient = bufferGlueCoefficient;
    }

    public BigDecimal getBufferGlueCoefficient() 
    {
        return bufferGlueCoefficient;
    }
    public void setBufferGlueDosage(BigDecimal bufferGlueDosage) 
    {
        this.bufferGlueDosage = bufferGlueDosage;
    }

    public BigDecimal getBufferGlueDosage() 
    {
        return bufferGlueDosage;
    }
    public void setLargeClothSpecifications(BigDecimal largeClothSpecifications) 
    {
        this.largeClothSpecifications = largeClothSpecifications;
    }

    public BigDecimal getLargeClothSpecifications() 
    {
        return largeClothSpecifications;
    }
    public void setLargeClothFrictioningCoefficient(BigDecimal largeClothFrictioningCoefficient) 
    {
        this.largeClothFrictioningCoefficient = largeClothFrictioningCoefficient;
    }

    public BigDecimal getLargeClothFrictioningCoefficient() 
    {
        return largeClothFrictioningCoefficient;
    }
    public void setLargeClothDosage(BigDecimal largeClothDosage) 
    {
        this.largeClothDosage = largeClothDosage;
    }

    public BigDecimal getLargeClothDosage() 
    {
        return largeClothDosage;
    }
    public void setMiddleGlue(String middleGlue) 
    {
        this.middleGlue = middleGlue;
    }

    public String getMiddleGlue() 
    {
        return middleGlue;
    }
    public void setMiddleGlueCoefficient(BigDecimal middleGlueCoefficient) 
    {
        this.middleGlueCoefficient = middleGlueCoefficient;
    }

    public BigDecimal getMiddleGlueCoefficient() 
    {
        return middleGlueCoefficient;
    }
    public void setMiddleGlueDosage(BigDecimal middleGlueDosage) 
    {
        this.middleGlueDosage = middleGlueDosage;
    }

    public BigDecimal getMiddleGlueDosage() 
    {
        return middleGlueDosage;
    }
    public void setDeviceUsageRestrictions(String deviceUsageRestrictions) 
    {
        this.deviceUsageRestrictions = deviceUsageRestrictions;
    }

    public String getDeviceUsageRestrictions() 
    {
        return deviceUsageRestrictions;
    }
    public void setWorkshopSection(String workshopSection) 
    {
        this.workshopSection = workshopSection;
    }

    public String getWorkshopSection() 
    {
        return workshopSection;
    }
    public void setClasses(String classes) 
    {
        this.classes = classes;
    }

    public String getClasses() 
    {
        return classes;
    }
    public void setTaskForce(String taskForce) 
    {
        this.taskForce = taskForce;
    }

    public String getTaskForce() 
    {
        return taskForce;
    }
    public void setTeamName(String teamName) 
    {
        this.teamName = teamName;
    }

    public String getTeamName() 
    {
        return teamName;
    }
    public void setGroupLeader(String groupLeader) 
    {
        this.groupLeader = groupLeader;
    }

    public String getGroupLeader() 
    {
        return groupLeader;
    }

    public List<HashMap<String, String>> getPersonnelOperationDetails() {
        return personnelOperationDetails;
    }

    public void setPersonnelOperationDetails(List<HashMap<String, String>> personnelOperationDetails) {
        this.personnelOperationDetails = personnelOperationDetails;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this,ToStringStyle.MULTI_LINE_STYLE)
            .append("objId", getObjId())
            .append("hardware", getHardware())
            .append("software", getSoftware())
            .append("stageText", getStageText())
            .append("seqNo", getSeqNo())
            .append("planStartTime", getPlanStartTime())
            .append("planEndTime", getPlanEndTime())
            .append("associationResource", getAssociationResource())
            .append("workingEfficiency", getWorkingEfficiency())
            .append("equipmentNo", getEquipmentNo())
            .append("preparationDuration", getPreparationDuration())
            .append("windUpDuration", getWindUpDuration())
            .append("clothMinimumSpeed", getClothMinimumSpeed())
            .append("clothMaximumSpeed", getClothMaximumSpeed())
            .append("formingMinimumSpeed", getFormingMinimumSpeed())
            .append("formingMaximumSpeed", getFormingMaximumSpeed())
            .append("glueMinimumSpeed", getGlueMinimumSpeed())
            .append("glueMaximumSpeed", getGlueMaximumSpeed())
            .append("sulfurizationLength", getSulfurizationLength())
            .append("vulcanizingMachineType", getVulcanizingMachineType())
            .append("vulcanizedBoardNumber", getVulcanizedBoardNumber())
            .append("resourceName", getResourceName())
            .append("processStage", getProcessStage())
            .append("preProcess", getPreProcess())
            .append("releaseOrder", getReleaseOrder())
            .append("taskCode", getTaskCode())
            .append("conveyorLengthSpecification", getConveyorLengthSpecification())
            .append("upGlueThickness", getUpGlueThickness())
            .append("upBufferGlueThickness", getUpBufferGlueThickness())
            .append("belowGlueThickness", getBelowGlueThickness())
            .append("belowBufferGlueThickness", getBelowBufferGlueThickness())
            .append("beltWidth", getBeltWidth())
            .append("customerRequestConveyorLength", getCustomerRequestConveyorLength())
            .append("rollingProductionMeters", getRollingProductionMeters())
            .append("vulcanizationMeters", getVulcanizationMeters())
            .append("recommendVulcanizationTime", getRecommendVulcanizationTime())
            .append("largeClothMeters", getLargeClothMeters())
            .append("smallClothMeters", getSmallClothMeters())
            .append("encapsulationMeters", getEncapsulationMeters())
            .append("workSpeed", getWorkSpeed())
            .append("workingHours", getWorkingHours())
            .append("distributionArea", getDistributionArea())
            .append("encapsulationArea", getEncapsulationArea())
            .append("vulcanizationArea", getVulcanizationArea())
            .append("conveyorTotalArea", getConveyorTotalArea())
            .append("glueProcess", getGlueProcess())
            .append("upGlue", getUpGlue())
            .append("upGlueCoefficient", getUpGlueCoefficient())
            .append("upGlueDosage", getUpGlueDosage())
            .append("belowGlue", getBelowGlue())
            .append("belowGlueCoefficient", getBelowGlueCoefficient())
            .append("belowGlueDosage", getBelowGlueDosage())
            .append("bufferGlue", getBufferGlue())
            .append("bufferGlueCoefficient", getBufferGlueCoefficient())
            .append("bufferGlueDosage", getBufferGlueDosage())
            .append("largeClothSpecifications", getLargeClothSpecifications())
            .append("largeClothFrictioningCoefficient", getLargeClothFrictioningCoefficient())
            .append("largeClothDosage", getLargeClothDosage())
            .append("middleGlue", getMiddleGlue())
            .append("middleGlueCoefficient", getMiddleGlueCoefficient())
            .append("middleGlueDosage", getMiddleGlueDosage())
            .append("deviceUsageRestrictions", getDeviceUsageRestrictions())
            .append("workshopSection", getWorkshopSection())
            .append("classes", getClasses())
            .append("taskForce", getTaskForce())
            .append("teamName", getTeamName())
            .append("groupLeader", getGroupLeader())
            .append("personnelOperationDetails", getPersonnelOperationDetails())
            .append("createBy", getCreateBy())
            .append("createTime", getCreateTime())
            .append("updateBy", getUpdateBy())
            .append("updateTime", getUpdateTime())
            .toString();
    }
}
