package com.os.mes.prod.service.impl;

import java.util.List;

import com.os.common.utils.DateUtils;
import com.os.common.utils.StringUtils;
import com.os.mes.base.domain.BaseDeviceLedger;
import com.os.mes.base.service.IBaseDeviceLedgerService;
import com.os.mes.prod.domain.ProdPlanInfo;
import com.os.mes.prod.service.IProdPlanInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.mes.prod.mapper.ProdPlanErpInfoMapper;
import com.os.mes.prod.domain.ProdPlanErpInfo;
import com.os.mes.prod.service.IProdPlanErpInfoService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 生产计划信息Service业务层处理
 *
 * @author Yinq
 * @date 2024-08-22
 */
@Service
public class ProdPlanErpInfoServiceImpl implements IProdPlanErpInfoService {
    @Autowired
    private ProdPlanErpInfoMapper prodPlanErpInfoMapper;

    @Autowired
    private IProdPlanInfoService prodPlanInfoService;

    @Autowired
    private IBaseDeviceLedgerService deviceLedgerService;

    /**
     * 查询生产计划信息
     *
     * @param objId 生产计划信息主键
     * @return 生产计划信息
     */
    @Override
    public ProdPlanErpInfo selectProdPlanErpInfoByObjId(Long objId) {
        return prodPlanErpInfoMapper.selectProdPlanErpInfoByObjId(objId);
    }

    /**
     * 查询生产计划信息列表
     *
     * @param prodPlanErpInfo 生产计划信息
     * @return 生产计划信息
     */
    @Override
    public List<ProdPlanErpInfo> selectProdPlanErpInfoList(ProdPlanErpInfo prodPlanErpInfo) {
        return prodPlanErpInfoMapper.selectProdPlanErpInfoList(prodPlanErpInfo);
    }

    /**
     * 新增生产计划信息
     *
     * @param prodPlanErpInfo 生产计划信息
     * @return 结果
     */
    @Override
    public int insertProdPlanErpInfo(ProdPlanErpInfo prodPlanErpInfo) {
        prodPlanErpInfo.setCreateTime(DateUtils.getNowDate());
        return prodPlanErpInfoMapper.insertProdPlanErpInfo(prodPlanErpInfo);
    }

    /**
     * 修改生产计划信息
     *
     * @param prodPlanErpInfo 生产计划信息
     * @return 结果
     */
    @Override
    public int updateProdPlanErpInfo(ProdPlanErpInfo prodPlanErpInfo) {
        prodPlanErpInfo.setUpdateTime(DateUtils.getNowDate());
        return prodPlanErpInfoMapper.updateProdPlanErpInfo(prodPlanErpInfo);
    }

    /**
     * 批量删除生产计划信息
     *
     * @param objIds 需要删除的生产计划信息主键
     * @return 结果
     */
    @Override
    public int deleteProdPlanErpInfoByObjIds(Long[] objIds) {
        return prodPlanErpInfoMapper.deleteProdPlanErpInfoByObjIds(objIds);
    }

    /**
     * 删除生产计划信息信息
     *
     * @param objId 生产计划信息主键
     * @return 结果
     */
    @Override
    public int deleteProdPlanErpInfoByObjId(Long objId) {
        return prodPlanErpInfoMapper.deleteProdPlanErpInfoByObjId(objId);
    }

    /**
     * 新增生产计划信息List
     *
     * @param dataList 生产计划信息
     * @return 结果
     */
    @Override
    @Transactional
    public void insertOrUpdateProdPlanErpInfoList(List<ProdPlanErpInfo> dataList) {
        for (ProdPlanErpInfo planErpInfo : dataList) {
            String equipmentNo = planErpInfo.getEquipmentNo();
            String processStage = planErpInfo.getProcessStage();
            if (StringUtils.isNotEmpty(equipmentNo)) {
                BaseDeviceLedger deviceLedger = deviceLedgerService.selectBaseDeviceLedgerByDeviceCode(equipmentNo, processStage);
                if (StringUtils.isNotNull(deviceLedger)) {
                    // 出布、成型、包胶、硫化
                    planErpInfo.setProcessCode(deviceLedger.getProcessCode());
                    planErpInfo.setStationCode(deviceLedger.getProductLineCode());
                }
            }
            String seqNo = planErpInfo.getSeqNo();
            ProdPlanErpInfo selectErpInfo = new ProdPlanErpInfo();
            selectErpInfo.setSeqNo(seqNo);
            List<ProdPlanErpInfo> infoList = prodPlanErpInfoMapper.selectProdPlanErpInfoList(selectErpInfo);
            if (!infoList.isEmpty()) {
                ProdPlanInfo prodPlanInfo = new ProdPlanInfo();
                prodPlanInfo.setPlanCode(seqNo);
                List<ProdPlanInfo> planInfoList = prodPlanInfoService.selectProdPlanInfoList(prodPlanInfo);
                ProdPlanInfo planInfo = planInfoList.get(0);
                planInfo.setPlanCode(seqNo);
                planInfo.setOrderCode(planErpInfo.getTaskCode());
                planInfo.setPlanAmount(planErpInfo.getWorkload());
                planInfo.setPlanBeginTime(planErpInfo.getPlanStartTime());
                planInfo.setPlanEndTime(planErpInfo.getPlanEndTime());
                planInfo.setDeviceCode(equipmentNo);
                planInfo.setProcessCode(planErpInfo.getProcessCode());
                planInfo.setStationCode(planErpInfo.getStationCode());
                planInfo.setTeamCode(planErpInfo.getTeamNo());
                planInfo.setMaterialName(planErpInfo.getConveyorLengthSpecification());
                prodPlanInfoService.updateProdPlanInfo(planInfo);
                ProdPlanErpInfo prodPlanErpInfo = infoList.get(0);
                planErpInfo.setObjId(prodPlanErpInfo.getObjId());
                this.updateProdPlanErpInfo(planErpInfo);
            } else {
                ProdPlanInfo planInfo = new ProdPlanInfo();
                planInfo.setPlanCode(planErpInfo.getSeqNo());
                planInfo.setOrderCode(planErpInfo.getTaskCode());
                planInfo.setPlanAmount(planErpInfo.getWorkload());
                planInfo.setDeviceCode(equipmentNo);
                planInfo.setProcessCode(planErpInfo.getProcessCode());
                planInfo.setStationCode(planErpInfo.getStationCode());
                planInfo.setPlanBeginTime(planErpInfo.getPlanStartTime());
                planInfo.setPlanEndTime(planErpInfo.getPlanEndTime());
                planInfo.setTeamCode(planErpInfo.getTeamNo());
                planInfo.setMaterialName(planErpInfo.getConveyorLengthSpecification());
                planInfo.setPlanStatus("0");
                planInfo.setImportFlag("1");
                prodPlanInfoService.insertProdPlanInfo(planInfo);
                this.insertProdPlanErpInfo(planErpInfo);
            }
        }
    }
}
