package com.os.mes.record.service.impl;

import java.util.List;

import com.os.common.utils.DateUtils;
import com.os.common.utils.StringUtils;
import com.os.mes.base.domain.BaseTeamMembers;
import com.os.mes.base.mapper.BaseTeamMembersMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.mes.record.mapper.RecordStaffAttendanceMapper;
import com.os.mes.record.domain.RecordStaffAttendance;
import com.os.mes.record.service.IRecordStaffAttendanceService;

/**
 * 员工打卡记录Service业务层处理
 *
 * @author Yinq
 * @date 2024-05-24
 */
@Service
public class RecordStaffAttendanceServiceImpl implements IRecordStaffAttendanceService {
    @Autowired
    private RecordStaffAttendanceMapper recordStaffAttendanceMapper;

    @Autowired
    private BaseTeamMembersMapper baseTeamMembersMapper;

    /**
     * 查询员工打卡记录
     *
     * @param objId 员工打卡记录主键
     * @return 员工打卡记录
     */
    @Override
    public RecordStaffAttendance selectRecordStaffAttendanceByObjId(Long objId) {
        return recordStaffAttendanceMapper.selectRecordStaffAttendanceByObjId(objId);
    }

    /**
     * 查询员工打卡记录列表
     *
     * @param recordStaffAttendance 员工打卡记录
     * @return 员工打卡记录
     */
    @Override
    public List<RecordStaffAttendance> selectRecordStaffAttendanceList(RecordStaffAttendance recordStaffAttendance) {
        List<RecordStaffAttendance> staffAttendanceList = recordStaffAttendanceMapper.selectRecordStaffAttendanceList(recordStaffAttendance);
        List<BaseTeamMembers> teamMembers = baseTeamMembersMapper.selectBaseTeamMembersList(new BaseTeamMembers());
        for (RecordStaffAttendance staffAttendance : staffAttendanceList) {
            if (StringUtils.isEmpty(staffAttendance.getTeamCode())) {
                continue;
            }
            for (BaseTeamMembers teamMember : teamMembers) {
                if (staffAttendance.getTeamCode().contains(teamMember.getTeamCode())) {
                    if (StringUtils.isEmpty(staffAttendance.getTeamName())) {
                        staffAttendance.setTeamName(teamMember.getTeamName());
                    } else {
                        staffAttendance.setTeamName(staffAttendance.getTeamName() + "," + teamMember.getTeamName());
                    }
                }
            }
        }
        return staffAttendanceList;
    }

    /**
     * 新增员工打卡记录
     *
     * @param recordStaffAttendance 员工打卡记录
     * @return 结果
     */
    @Override
    public int insertRecordStaffAttendance(RecordStaffAttendance recordStaffAttendance) {
        recordStaffAttendance.setCreateTime(DateUtils.getNowDate());
        return recordStaffAttendanceMapper.insertRecordStaffAttendance(recordStaffAttendance);
    }

    /**
     * 修改员工打卡记录
     *
     * @param recordStaffAttendance 员工打卡记录
     * @return 结果
     */
    @Override
    public int updateRecordStaffAttendance(RecordStaffAttendance recordStaffAttendance) {
        recordStaffAttendance.setUpdateTime(DateUtils.getNowDate());
        return recordStaffAttendanceMapper.updateRecordStaffAttendance(recordStaffAttendance);
    }

    /**
     * 批量删除员工打卡记录
     *
     * @param objIds 需要删除的员工打卡记录主键
     * @return 结果
     */
    @Override
    public int deleteRecordStaffAttendanceByObjIds(Long[] objIds) {
        return recordStaffAttendanceMapper.deleteRecordStaffAttendanceByObjIds(objIds);
    }

    /**
     * 删除员工打卡记录信息
     *
     * @param objId 员工打卡记录主键
     * @return 结果
     */
    @Override
    public int deleteRecordStaffAttendanceByObjId(Long objId) {
        return recordStaffAttendanceMapper.deleteRecordStaffAttendanceByObjId(objId);
    }
}
