package com.os.mes.record.service.impl;

import java.util.List;

import com.os.common.utils.DateUtils;
import com.os.common.utils.StringUtils;
import com.os.mes.base.domain.BaseTeamMembers;
import com.os.mes.base.mapper.BaseTeamMembersMapper;
import com.os.mes.record.domain.RecordStaffAttendance;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.os.mes.record.mapper.RecordStaffCommuteMapper;
import com.os.mes.record.domain.RecordStaffCommute;
import com.os.mes.record.service.IRecordStaffCommuteService;

/**
 * 员工上下班记录Service业务层处理
 *
 * @author Yinq
 * @date 2024-07-01
 */
@Service
public class RecordStaffCommuteServiceImpl implements IRecordStaffCommuteService {
    @Autowired
    private RecordStaffCommuteMapper recordStaffCommuteMapper;

    @Autowired
    private BaseTeamMembersMapper baseTeamMembersMapper;

    /**
     * 查询员工上下班记录
     *
     * @param objId 员工上下班记录主键
     * @return 员工上下班记录
     */
    @Override
    public RecordStaffCommute selectRecordStaffCommuteByObjId(Long objId) {
        return recordStaffCommuteMapper.selectRecordStaffCommuteByObjId(objId);
    }

    /**
     * 查询员工上下班记录列表
     *
     * @param recordStaffCommute 员工上下班记录
     * @return 员工上下班记录
     */
    @Override
    public List<RecordStaffCommute> selectRecordStaffCommuteList(RecordStaffCommute recordStaffCommute) {
        List<RecordStaffCommute> staffCommuteList = recordStaffCommuteMapper.selectRecordStaffCommuteList(recordStaffCommute);
        List<BaseTeamMembers> teamMembers = baseTeamMembersMapper.selectBaseTeamMembersList(new BaseTeamMembers());
        for (RecordStaffCommute staffAttendance : staffCommuteList) {
            if (StringUtils.isEmpty(staffAttendance.getTeamCode())) {
                continue;
            }
            for (BaseTeamMembers teamMember : teamMembers) {
                if (staffAttendance.getTeamCode().contains(teamMember.getTeamCode())) {
                    if (StringUtils.isEmpty(staffAttendance.getTeamName())) {
                        staffAttendance.setTeamName(teamMember.getTeamName());
                    } else {
                        staffAttendance.setTeamName(staffAttendance.getTeamName() + "," + teamMember.getTeamName());
                    }
                }
            }
        }
        return staffCommuteList;
    }

    /**
     * 新增员工上下班记录
     *
     * @param recordStaffCommute 员工上下班记录
     * @return 结果
     */
    @Override
    public int insertRecordStaffCommute(RecordStaffCommute recordStaffCommute) {
        recordStaffCommute.setCreateTime(DateUtils.getNowDate());
        return recordStaffCommuteMapper.insertRecordStaffCommute(recordStaffCommute);
    }

    /**
     * 修改员工上下班记录
     *
     * @param recordStaffCommute 员工上下班记录
     * @return 结果
     */
    @Override
    public int updateRecordStaffCommute(RecordStaffCommute recordStaffCommute) {
        recordStaffCommute.setUpdateTime(DateUtils.getNowDate());
        return recordStaffCommuteMapper.updateRecordStaffCommute(recordStaffCommute);
    }

    /**
     * 批量删除员工上下班记录
     *
     * @param objIds 需要删除的员工上下班记录主键
     * @return 结果
     */
    @Override
    public int deleteRecordStaffCommuteByObjIds(Long[] objIds) {
        return recordStaffCommuteMapper.deleteRecordStaffCommuteByObjIds(objIds);
    }

    /**
     * 删除员工上下班记录信息
     *
     * @param objId 员工上下班记录主键
     * @return 结果
     */
    @Override
    public int deleteRecordStaffCommuteByObjId(Long objId) {
        return recordStaffCommuteMapper.deleteRecordStaffCommuteByObjId(objId);
    }
}
