package com.os.mes.report.controller;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.os.common.core.page.TableDataInfo;
import com.os.common.utils.poi.ExcelUtil;
import com.os.mes.record.domain.ReportSalarySummary;
import com.os.mes.record.service.IRecordStaffSalaryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.mes.report.domain.ReportBoardPort;
import com.os.mes.report.service.IReportBoardPortService;

import javax.servlet.http.HttpServletResponse;

/**
 * 看板接口Controller
 * 
 * @author Yinq
 * @date 2024-07-11
 */
@RestController
@RequestMapping("/mes/boardPort")
public class ReportBoardPortController extends BaseController
{
    @Autowired
    private IReportBoardPortService reportBoardPortService;

    @Autowired
    private IRecordStaffSalaryService recordStaffSalaryService;

    /**
     * 查询看板接口列表
     */
    @GetMapping("/list")
    public AjaxResult list(ReportBoardPort reportBoardPort)
    {
        List<ReportBoardPort> list = reportBoardPortService.selectReportBoardPortList(reportBoardPort);
        return success(list);
    }

    /**
     * 首页看板接口
     * @param paramMap
     * @return
     */
    @PostMapping("/homeBoard")
    public AjaxResult homeBoard(@RequestBody HashMap<String, String> paramMap)
    {
        HashMap<String, Object> list = reportBoardPortService.selectReportHomeBoard(paramMap);
        return success(list);
    }

    /**
     * 员工工资汇总报表
     * @param hashMap
     * @return
     */
    @GetMapping("/salarySummaryReport")
    public TableDataInfo salarySummaryReport(@RequestParam(required = false) Map hashMap) {
        startPage();
        List<ReportSalarySummary> list = recordStaffSalaryService.salarySummaryReport(hashMap);
        return getDataTable(list);
    }

    /**
     * 导出员工工资汇总报表
     */
    @PostMapping("/salarySummaryReport/export" )
    public void energyStatisticalReportListExport(HttpServletResponse response, @RequestParam(required = false) Map hashMap) {
        List<ReportSalarySummary> list = recordStaffSalaryService.salarySummaryReport(hashMap);
        ExcelUtil<ReportSalarySummary> util = new ExcelUtil<>(ReportSalarySummary. class);
        util.exportExcel(response, list, "员工工资汇总报表" );
    }

}
